@@ -2,7 +2,7 @@
     Copyright (C) 2007-2008 Tanguy Krotoff <tkrotoff@gmail.com>
     Copyright (C) 2008 Lukas Durfina <lukas.durfina@gmail.com>
     Copyright (C) 2009 Fathi Boudra <fabo@kde.org>
-    Copyright (C) 2013-2015 Harald Sitter <sitter@kde.org>
+    Copyright (C) 2013-2018 Harald Sitter <sitter@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -34,9 +34,11 @@ namespace Phonon {
 namespace VLC {
 
 AudioOutput::AudioOutput(QObject *parent)
-    : QObject(parent),
-      m_volume(1.0)
+    : QObject(parent)
+    , m_volume(0.75)
+    , m_explicitVolume(false)
     , m_muted(false)
+    , m_category(Phonon::NoCategory)
 {
 }
 
@@ -44,28 +46,53 @@ AudioOutput::~AudioOutput()
 {
 }
 
+#if (LIBVLC_VERSION_INT >= LIBVLC_VERSION(3, 0, 0, 0))
+static libvlc_media_player_role categoryToRole(Category category)
+{
+    switch(category) {
+    case NoCategory:
+        return libvlc_role_None;
+    case NotificationCategory:
+        return libvlc_role_Notification;
+    case MusicCategory:
+        return libvlc_role_Music;
+    case VideoCategory:
+        return libvlc_role_Video;
+    case CommunicationCategory:
+        return libvlc_role_Communication;
+    case GameCategory:
+        return libvlc_role_Game;
+    case AccessibilityCategory:
+        return libvlc_role_Accessibility;
+    }
+    return libvlc_role_None;
+}
+#endif
+
 void AudioOutput::handleConnectToMediaObject(MediaObject *mediaObject)
 {
     Q_UNUSED(mediaObject);
     setOutputDeviceImplementation();
     if (!PulseSupport::getInstance()->isActive()) {
+        // Rely on libvlc for updates if PASupport is not active
         connect(m_player, SIGNAL(mutedChanged(bool)),
                 this, SLOT(onMutedChanged(bool)));
         connect(m_player, SIGNAL(volumeChanged(float)),
                 this, SLOT(onVolumeChanged(float)));
         applyVolume();
     }
+#if (LIBVLC_VERSION_INT >= LIBVLC_VERSION(3, 0, 0, 0))
+    libvlc_media_player_set_role(*m_player, categoryToRole(m_category));
+#endif
 }
 
 void AudioOutput::handleAddToMedia(Media *media)
 {
     media->addOption(":audio");
-#if (PHONON_VERSION >= PHONON_VERSION_CHECK(4, 6, 50))
     PulseSupport *pulse = PulseSupport::getInstance();
     if (pulse && pulse->isActive()) {
         pulse->setupStreamEnvironment(m_streamUuid);
     }
-#endif
 }
 
 qreal AudioOutput::volume() const
@@ -78,6 +105,7 @@ void AudioOutput::setVolume(qreal volume)
     if (m_player) {
         debug() << "async setting of volume to" << volume;
         m_volume = volume;
+        m_explicitVolume = true;
         applyVolume();
 
 #if (LIBVLC_VERSION_INT < LIBVLC_VERSION(2, 2, 2, 0))
@@ -86,7 +114,6 @@ void AudioOutput::setVolume(qreal volume)
     }
 }
 
-#if (PHONON_VERSION >= PHONON_VERSION_CHECK(4, 8, 50))
 void AudioOutput::setMuted(bool mute)
 {
     if (mute == m_player->mute()) {
@@ -96,7 +123,11 @@ void AudioOutput::setMuted(bool mute)
     }
     m_player->setMute(mute);
 }
-#endif
+
+void AudioOutput::setCategory(Category category)
+{
+    m_category = category;
+}
 
 int AudioOutput::outputDevice() const
 {
@@ -113,7 +144,6 @@ bool AudioOutput::setOutputDevice(int deviceIndex)
     return setOutputDevice(device);
 }
 
-#if (PHONON_VERSION >= PHONON_VERSION_CHECK(4, 2, 0))
 bool AudioOutput::setOutputDevice(const AudioOutputDevice &newDevice)
 {
     debug() << Q_FUNC_INFO;
@@ -133,16 +163,13 @@ bool AudioOutput::setOutputDevice(const AudioOutputDevice &newDevice)
 
     return true;
 }
-#endif
 
-#if (PHONON_VERSION >= PHONON_VERSION_CHECK(4, 6, 50))
 void AudioOutput::setStreamUuid(QString uuid)
 {
     DEBUG_BLOCK;
     debug() << uuid;
     m_streamUuid = uuid;
 }
-#endif
 
 void AudioOutput::setOutputDeviceImplementation()
 {
@@ -193,7 +220,7 @@ void AudioOutput::setOutputDeviceImplementation()
 
 void AudioOutput::applyVolume()
 {
-    if (m_player) {
+    if (m_player && m_explicitVolume) {
         const int preVolume = m_player->audioVolume();
         const int newVolume = m_volume * 100;
         m_player->setAudioVolume(newVolume);
@@ -211,11 +238,6 @@ void AudioOutput::onMutedChanged(bool mute)
 {
     m_muted = mute;
     emit mutedChanged(mute);
-#if (PHONON_VERSION < PHONON_VERSION_CHECK(4, 8, 51))
-    // Previously we had no interface signal to communicate mutness, so instead
-    // emit volume.
-    mute ? emit volumeChanged(0.0) : emit volumeChanged(volume());
-#endif
 }
 
 void AudioOutput::onVolumeChanged(float volume)
